All of lore.kernel.org
 help / color / mirror / Atom feed
From: Stuart Summers <stuart.summers@intel.com>
Cc: stuart.summers@intel.com, matthew.brost@intel.com,
	lucas.demarchi@intel.com, nirmoy.das@linux.intel.com,
	intel-xe@lists.freedesktop.org, Nirmoy Das <nirmoy.das@intel.com>
Subject: [PATCH 1/2] drm/xe: s/tlb_invalidation.lock/tlb_invalidation.fence_lock
Date: Wed, 16 Apr 2025 18:30:31 +0000	[thread overview]
Message-ID: <20250416183032.70948-1-stuart.summers@intel.com> (raw)

From: Matthew Brost <matthew.brost@intel.com>

tlb_invalidation.lock is the lock for GT TLB invalidation fences, name
this accurately.

Signed-off-by: Matthew Brost <matthew.brost@intel.com>
Signed-off-by: Nirmoy Das <nirmoy.das@intel.com>
---
 drivers/gpu/drm/xe/xe_gt_tlb_invalidation.c | 8 ++++----
 drivers/gpu/drm/xe/xe_gt_types.h            | 4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/drivers/gpu/drm/xe/xe_gt_tlb_invalidation.c b/drivers/gpu/drm/xe/xe_gt_tlb_invalidation.c
index 084cbdeba8ea..031c4d43f36b 100644
--- a/drivers/gpu/drm/xe/xe_gt_tlb_invalidation.c
+++ b/drivers/gpu/drm/xe/xe_gt_tlb_invalidation.c
@@ -119,7 +119,7 @@ int xe_gt_tlb_invalidation_init_early(struct xe_gt *gt)
 	gt->tlb_invalidation.seqno = 1;
 	INIT_LIST_HEAD(&gt->tlb_invalidation.pending_fences);
 	spin_lock_init(&gt->tlb_invalidation.pending_lock);
-	spin_lock_init(&gt->tlb_invalidation.lock);
+	spin_lock_init(&gt->tlb_invalidation.fence_lock);
 	INIT_DELAYED_WORK(&gt->tlb_invalidation.fence_tdr,
 			  xe_gt_tlb_fence_timeout);
 
@@ -564,11 +564,11 @@ void xe_gt_tlb_invalidation_fence_init(struct xe_gt *gt,
 {
 	xe_pm_runtime_get_noresume(gt_to_xe(gt));
 
-	spin_lock_irq(&gt->tlb_invalidation.lock);
+	spin_lock_irq(&gt->tlb_invalidation.fence_lock);
 	dma_fence_init(&fence->base, &invalidation_fence_ops,
-		       &gt->tlb_invalidation.lock,
+		       &gt->tlb_invalidation.fence_lock,
 		       dma_fence_context_alloc(1), 1);
-	spin_unlock_irq(&gt->tlb_invalidation.lock);
+	spin_unlock_irq(&gt->tlb_invalidation.fence_lock);
 	INIT_LIST_HEAD(&fence->link);
 	if (stack)
 		set_bit(FENCE_STACK_BIT, &fence->base.flags);
diff --git a/drivers/gpu/drm/xe/xe_gt_types.h b/drivers/gpu/drm/xe/xe_gt_types.h
index 7def0959da35..be81687cbe2b 100644
--- a/drivers/gpu/drm/xe/xe_gt_types.h
+++ b/drivers/gpu/drm/xe/xe_gt_types.h
@@ -210,8 +210,8 @@ struct xe_gt {
 		 * xe_gt_tlb_fence_timeout after the timeut interval is over.
 		 */
 		struct delayed_work fence_tdr;
-		/** @tlb_invalidation.lock: protects TLB invalidation fences */
-		spinlock_t lock;
+		/** @tlb_invalidation.fence_lock: protects TLB invalidation fences */
+		spinlock_t fence_lock;
 	} tlb_invalidation;
 
 	/**
-- 
2.34.1


             reply	other threads:[~2025-04-16 18:30 UTC|newest]

Thread overview: 9+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-04-16 18:30 Stuart Summers [this message]
2025-04-16 18:30 ` [PATCH 2/2] drm/xe: Do not use CT lock in TLB code Stuart Summers
2025-04-16 19:22   ` Matthew Brost
2025-04-16 19:24   ` Summers, Stuart
2025-04-16 19:23 ` [PATCH 1/2] drm/xe: s/tlb_invalidation.lock/tlb_invalidation.fence_lock Summers, Stuart
2025-04-17  0:35   ` Matthew Brost
2025-04-16 20:54 ` ✓ Xe.CI.BAT: success for series starting with [1/2] " Patchwork
2025-04-17  7:31 ` ✗ Xe.CI.Full: failure " Patchwork
2025-04-17 22:39   ` Summers, Stuart

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20250416183032.70948-1-stuart.summers@intel.com \
    --to=stuart.summers@intel.com \
    --cc=intel-xe@lists.freedesktop.org \
    --cc=lucas.demarchi@intel.com \
    --cc=matthew.brost@intel.com \
    --cc=nirmoy.das@intel.com \
    --cc=nirmoy.das@linux.intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.